@@ -1,16 +1,18 @@
 """
 Unit test file.
 """
-import unittest
 import os
+import unittest
+
+COMMAND = "test_cmd"
 
 
 class MainTester(unittest.TestCase):
     """Main tester class."""
 
-    def test_playaudio(self) -> None:
+    def test_imports(self) -> None:
         """Test command line interface (CLI)."""
-        rtn = os.system("playaudio")
+        rtn = os.system(COMMAND)
         self.assertEqual(0, rtn)
 
 
